<template>
  <div class="AlarmHandlingAnalysis">
    <div class="titleContainer">
      <div class="left">
        <div class="title">当月报警</div>
        <div class="alarmMonth">
          <span>{{ monthNumObj.num1 }}</span>
          <span>{{ monthNumObj.num2 }}</span>
          <span>{{ monthNumObj.num3 }}</span>
          <span>{{ monthNumObj.num4 }}</span>
        </div>
      </div>
      <div class="right">
        <ul>
          <li v-for="(item, index) in dataLists" :key="index">
            <div class="container">
              <div class="iconBox">
                <i><img :src="item.img" alt="" /></i>
              </div>
              <div class="titleNum">
                <div class="title">
                  <span>{{ item.name }}</span>
                </div>
                <div class="num">
                  <span>{{ item.num }}</span>
                </div>
              </div>
            </div>
          </li>
        </ul>
      </div>
    </div>
    <div class="tableContainer">
      <table-scroll
        :listDatas="listDatas"
        :stepNum="stepNum"
        :className="className"
      >
        <el-table-column
          :prop="column.fieldName"
          :label="column.name"
          v-for="column in titleDatas"
          :key="column.fieldName"
          :width="column.width"
          align="center"
          :show-overflow-tooltip="true"
        >
          <template slot-scope="scope">
            <template v-if="column.fieldName == 'status'">
              <span
                :style="{
                  color:
                    scope.row[column.fieldName] == 0
                      ? '#FFB756'
                      : scope.row[column.fieldName] == 1
                      ? '#00C6FF'
                      : '#FFFFFF',
                }"
                >{{
                  scope.row[column.fieldName] == 0
                    ? "未处置"
                    : scope.row[column.fieldName] == 1
                    ? "处置中"
                    : "已处置"
                }}</span
              >
            </template>
            <template v-else-if="column.fieldName == 'grade'">
              <span
                :style="{
                  color:
                    scope.row[column.fieldName] == '一级'
                      ? '#DF3747'
                      : scope.row[column.fieldName] == '二级'
                      ? '#FFB756'
                      : '#EEE968',
                }"
              >
                {{
                  scope.row[column.fieldName] == "一级"
                    ? "一级"
                    : scope.row[column.fieldName] == "二级"
                    ? "二级"
                    : "三级"
                }}
              </span>
            </template>
            <template v-else>
              <span>{{ scope.row[column.fieldName] }}</span>
            </template>
          </template>
        </el-table-column>
      </table-scroll>
    </div>
  </div>
</template>

<script>
export default {
  name: "AlarmHandlingAnalysis",
  components: {},
  data() {
    return {
      monthNumObj: {
        num1: 0,
        num2: 3,
        num3: 9,
        num4: 7,
      },
      dataLists: [
        {
          id: 1,
          img: require("./handleIcon1.png"),
          name: "未处置",
          num: 7,
        },
        {
          id: 2,
          img: require("./handleIcon2.png"),
          name: "处置中",
          num: 13,
        },
        {
          id: 3,
          img: require("./handleIcon3.png"),
          name: "已处置",
          num: 377,
        },
      ],
      listDatas: [],
      titleDatas: [],
      stepNum: 0,
      className: "",
    };
  },
  created() {
    this.init();
  },
  methods: {
    init() {
      this.stepNum = 0.5;
      this.listDatas = [
        {
          id: 1,
          typeName: "燃气",
          grade: "一级",
          address: "太白南路与科技二路交叉口",
          alarmTime: "2022-06-15 16:32:38",
          project: "燃气",
          status: 0,
        },
        {
          id: 2,
          typeName: "桥梁",
          grade: "二级",
          address: "长安中路与小寨西路交叉口",
          alarmTime: "2022-10-21 13:18:26",
          project: "桥梁",
          status: 1,
        },
        {
          id: 3,
          typeName: "供水",
          grade: "一级",
          address: "太乙路和咸宁西路交叉口向东200米",
          alarmTime: "2021-08-22 19:23:46",
          project: "供水",
          status: 2,
        },
      ];
      this.titleDatas = [
        {
          id: 1,
          name: "类型",
          fieldName: "typeName",
        },
        {
          id: 2,
          name: "级别",
          fieldName: "grade",
        },
        {
          id: 3,
          name: "位置",
          fieldName: "address",
          width: 300,
        },
        {
          id: 4,
          name: "报警时间",
          fieldName: "alarmTime",
          width: 180,
        },
        {
          id: 5,
          name: "所属专项",
          fieldName: "project",
        },
        {
          id: 6,
          name: "状态",
          fieldName: "status",
        },
      ];
    },
  },
};
</script>

<style lang="scss" scoped>
.AlarmHandlingAnalysis {
  position: absolute;
  width: 100%;
  height: calc(100% - 49px);
  top: 49px;
  box-sizing: border-box;
  .titleContainer {
    width: 100%;
    height: 75px;
    overflow: hidden;
    .left {
      float: left;
      width: 317px;
      overflow: hidden;
      .title {
        float: left;
        padding: 0 20px 0 42px;
        font-size: 16px;
        font-family: Alimama ShuHeiTi;
        font-weight: bold;
        color: #ffffff;
        line-height: 86px;
        opacity: 0.8;
      }
      .alarmMonth {
        float: left;
        text-align: center;
        overflow: hidden;
        margin-top: 26px;
        span {
          float: left;
          width: 25px;
          height: 34px;
          margin-right: 8px;
          line-height: 34px;
          background: url("./numBg.png") no-repeat;
          background-size: 100% 100%;
          font-size: 28px;
          font-family: DIN;
          font-weight: bold;
          color: #ffffff;
          text-shadow: 0px 3px 1px rgba(255, 255, 255, 0.44);
        }
      }
    }
    .right {
      float: left;
      width: calc(100% - 317px);
      padding: 0 42px 0 0;
      box-sizing: border-box;
      ul {
        display: flex;
        justify-content: space-between;
        li {
          .container {
            overflow: hidden;
            .iconBox {
              float: left;
              i {
                display: block;
                width: 80px;
                height: 60px;
                margin-top: 15px;
                img {
                  width: 100%;
                  height: 100%;
                }
              }
            }
            .titleNum {
              float: left;
              padding: 22px 0 0 8px;
              box-sizing: border-box;
              .title {
                span {
                  font-size: 14px;
                  font-family: Alimama ShuHeiTi;
                  font-weight: bold;
                  opacity: 0.6;
                  line-height: 14px;
                }
              }
              .num {
                margin-top: 5px;
                span {
                  font-size: 19px;
                  font-family: DIN Alternate;
                  font-weight: bold;
                  line-height: 20px;
                }
              }
            }
          }
          &:nth-child(1) {
            .container {
              .iconBox {
                i {
                  margin-top: 0;
                  width: 85px;
                  height: 75px;
                }
              }
              .titleNum {
                .title {
                  span {
                    color: #df3747;
                  }
                }
                .num {
                  span {
                    color: #df3747;
                  }
                }
              }
            }
          }
          &:nth-child(2) {
            .container {
              .titleNum {
                .title {
                  span {
                    color: #00c6ff;
                  }
                }
                .num {
                  span {
                    color: #00c6ff;
                  }
                }
              }
            }
          }
          &:nth-child(3) {
            .container {
              .titleNum {
                .title {
                  span {
                    color: #56ffa5;
                  }
                }
                .num {
                  span {
                    color: #56ffa5;
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  .tableContainer {
    width: 100%;
    height: calc(100% - 75px);
    padding: 0 15px 5px 10px;
    box-sizing: border-box;
  }
}
</style>